# The hg38 assemblies on Ensembl uses p11
# while the UCSC browser only uses the base assembly.
# The following lines download the conversion tables for
# the base assembly and patch 11 respectively
# For some reason, UCSC still provides data for patch11,
# but apparently new patches are not supported on the browser

# mysql --user=genome --host=genome-mysql.cse.ucsc.edu -A -N -e "select * from ucscToEnsembl;" hg38 | awk '{printf("\"%s\": \"%s\",\n", $1,$2)}'
# wget -nv -O - ftp://hgdownload.soe.ucsc.edu/goldenPath/hg38/hg38Patch11/README.txt | awk '$1~/chr/ {printf("\"%s\": \"CHR_%s\",\n", $2,$4)}'

# The mm10 assembly on Ensembl is p5, whereas UCSC
# provides data for p4 (see here: http://genome-euro.ucsc.edu/cgi-bin/hgTracks?chromInfoPage=)
# Like for human, the browser does not support patches at all

# mysql --user=genome --host=genome-mysql.cse.ucsc.edu -A -N -e "select * from ucscToEnsembl;" mm10 | awk '{printf("\"%s\": \"%s\",\n", $1,$2)}'
# wget -nv -O - ftp://hgdownload.soe.ucsc.edu/goldenPath/mm10/mm10Patch4/README.txt | awk '$1~/chr/ {printf("\"%s\": \"CHR_%s\",\n", $2,$4)}'


hg38_ucsc2ensembl = { 
   "chr1": "1",
   "chr10": "10",
   "chr10_GL383545v1_alt": "CHR_HSCHR10_1_CTG1",
   "chr10_GL383546v1_alt": "CHR_HSCHR10_1_CTG2",
   "chr10_KI270824v1_alt": "CHR_HSCHR10_1_CTG3",
   "chr10_KI270825v1_alt": "CHR_HSCHR10_1_CTG4",
   "chr11": "11",
   "chr11_GL383547v1_alt": "CHR_HSCHR11_1_CTG1_1",
   "chr11_JH159136v1_alt": "CHR_HG142_HG150_NOVEL_TEST",
   "chr11_JH159137v1_alt": "CHR_HG151_NOVEL_TEST",
   "chr11_KI270721v1_random": "KI270721.1",
   "chr11_KI270826v1_alt": "CHR_HSCHR11_1_CTG2",
   "chr11_KI270827v1_alt": "CHR_HSCHR11_1_CTG3",
   "chr11_KI270829v1_alt": "CHR_HSCHR11_1_CTG5",
   "chr11_KI270830v1_alt": "CHR_HSCHR11_1_CTG6",
   "chr11_KI270831v1_alt": "CHR_HSCHR11_1_CTG7",
   "chr11_KI270832v1_alt": "CHR_HSCHR11_1_CTG8",
   "chr11_KI270902v1_alt": "CHR_HSCHR11_2_CTG1",
   "chr11_KI270903v1_alt": "CHR_HSCHR11_2_CTG1_1",
   "chr11_KI270927v1_alt": "CHR_HSCHR11_3_CTG1",
   "chr12": "12",
   "chr12_GL383549v1_alt": "CHR_HSCHR12_1_CTG2",
   "chr12_GL383550v2_alt": "CHR_HSCHR12_1_CTG2_1",
   "chr12_GL383551v1_alt": "CHR_HSCHR12_4_CTG2_1",
   "chr12_GL383552v1_alt": "CHR_HSCHR12_2_CTG2_1",
   "chr12_GL383553v2_alt": "CHR_HSCHR12_3_CTG2_1",
   "chr12_GL877875v1_alt": "CHR_HSCHR12_1_CTG1",
   "chr12_GL877876v1_alt": "CHR_HSCHR12_2_CTG2",
   "chr12_KI270833v1_alt": "CHR_HSCHR12_5_CTG2_1",
   "chr12_KI270834v1_alt": "CHR_HSCHR12_6_CTG2_1",
   "chr12_KI270835v1_alt": "CHR_HSCHR12_4_CTG2",
   "chr12_KI270836v1_alt": "CHR_HSCHR12_7_CTG2_1",
   "chr12_KI270837v1_alt": "CHR_HSCHR12_5_CTG2",
   "chr12_KI270904v1_alt": "CHR_HSCHR12_3_CTG2",
   "chr13": "13",
   "chr13_KI270838v1_alt": "CHR_HSCHR13_1_CTG1",
   "chr13_KI270839v1_alt": "CHR_HSCHR13_1_CTG2",
   "chr13_KI270840v1_alt": "CHR_HSCHR13_1_CTG3",
   "chr13_KI270841v1_alt": "CHR_HSCHR13_1_CTG4",
   "chr13_KI270842v1_alt": "CHR_HSCHR13_1_CTG5",
   "chr13_KI270843v1_alt": "CHR_HSCHR13_1_CTG6",
   "chr14": "14",
   "chr14_GL000009v2_random": "GL000009.2",
   "chr14_GL000194v1_random": "GL000194.1",
   "chr14_GL000225v1_random": "GL000225.1",
   "chr14_KI270722v1_random": "KI270722.1",
   "chr14_KI270723v1_random": "KI270723.1",
   "chr14_KI270724v1_random": "KI270724.1",
   "chr14_KI270725v1_random": "KI270725.1",
   "chr14_KI270726v1_random": "KI270726.1",
   "chr14_KI270844v1_alt": "CHR_HSCHR14_1_CTG1",
   "chr14_KI270845v1_alt": "CHR_HSCHR14_2_CTG1",
   "chr14_KI270846v1_alt": "CHR_HSCHR14_3_CTG1",
   "chr14_KI270847v1_alt": "CHR_HSCHR14_7_CTG1",
   "chr15": "15",
   "chr15_GL383554v1_alt": "CHR_HSCHR15_1_CTG8",
   "chr15_GL383555v2_alt": "CHR_HSCHR15_2_CTG8",
   "chr15_KI270727v1_random": "KI270727.1",
   "chr15_KI270848v1_alt": "CHR_HSCHR15_1_CTG3",
   "chr15_KI270849v1_alt": "CHR_HSCHR15_3_CTG8",
   "chr15_KI270850v1_alt": "CHR_HSCHR15_5_CTG8",
   "chr15_KI270851v1_alt": "CHR_HSCHR15_3_CTG3",
   "chr15_KI270852v1_alt": "CHR_HSCHR15_1_CTG1",
   "chr15_KI270905v1_alt": "CHR_HSCHR15_4_CTG8",
   "chr15_KI270906v1_alt": "CHR_HSCHR15_2_CTG3",
   "chr16": "16",
   "chr16_GL383556v1_alt": "CHR_HSCHR16_1_CTG3_1",
   "chr16_GL383557v1_alt": "CHR_HSCHR16_2_CTG3_1",
   "chr16_KI270728v1_random": "KI270728.1",
   "chr16_KI270853v1_alt": "CHR_HSCHR16_1_CTG1",
   "chr16_KI270854v1_alt": "CHR_HSCHR16_CTG2",
   "chr16_KI270855v1_alt": "CHR_HSCHR16_3_CTG1",
   "chr16_KI270856v1_alt": "CHR_HSCHR16_4_CTG1",
   "chr17": "17",
   "chr17_GL000205v2_random": "GL000205.2",
   "chr17_GL000258v2_alt": "CHR_HSCHR17_1_CTG5",
   "chr17_GL383563v3_alt": "CHR_HSCHR17_1_CTG1",
   "chr17_GL383564v2_alt": "CHR_HSCHR17_1_CTG4",
   "chr17_GL383565v1_alt": "CHR_HSCHR17_2_CTG4",
   "chr17_GL383566v1_alt": "CHR_HSCHR17_3_CTG4",
   "chr17_JH159146v1_alt": "CHR_HSCHR17_4_CTG4",
   "chr17_JH159147v1_alt": "CHR_HSCHR17_5_CTG4",
   "chr17_JH159148v1_alt": "CHR_HSCHR17_6_CTG4",
   "chr17_KI270729v1_random": "KI270729.1",
   "chr17_KI270730v1_random": "KI270730.1",
   "chr17_KI270857v1_alt": "CHR_HSCHR17_7_CTG4",
   "chr17_KI270858v1_alt": "CHR_HSCHR17_8_CTG4",
   "chr17_KI270859v1_alt": "CHR_HSCHR17_9_CTG4",
   "chr17_KI270860v1_alt": "CHR_HSCHR17_1_CTG9",
   "chr17_KI270861v1_alt": "CHR_HSCHR17_1_CTG2",
   "chr17_KI270862v1_alt": "CHR_HSCHR17_2_CTG2",
   "chr17_KI270907v1_alt": "CHR_HSCHR17_2_CTG1",
   "chr17_KI270908v1_alt": "CHR_HSCHR17_2_CTG5",
   "chr17_KI270909v1_alt": "CHR_HSCHR17_10_CTG4",
   "chr17_KI270910v1_alt": "CHR_HSCHR17_3_CTG2",
   "chr18": "18",
   "chr18_GL383567v1_alt": "CHR_HSCHR18_1_CTG1_1",
   "chr18_GL383568v1_alt": "CHR_HSCHR18_1_CTG2",
   "chr18_GL383569v1_alt": "CHR_HSCHR18_1_CTG2_1",
   "chr18_GL383570v1_alt": "CHR_HSCHR18_2_CTG1_1",
   "chr18_GL383571v1_alt": "CHR_HSCHR18_2_CTG2",
   "chr18_GL383572v1_alt": "CHR_HSCHR18_2_CTG2_1",
   "chr18_KI270863v1_alt": "CHR_HSCHR18_3_CTG2_1",
   "chr18_KI270864v1_alt": "CHR_HSCHR18_4_CTG1_1",
   "chr18_KI270911v1_alt": "CHR_HSCHR18_ALT2_CTG2_1",
   "chr18_KI270912v1_alt": "CHR_HSCHR18_ALT21_CTG2_1",
   "chr19": "19",
   "chr19_GL000209v2_alt": "CHR_HSCHR19KIR_RP5_B_HAP_CTG3_1",
   "chr19_GL383573v1_alt": "CHR_HSCHR19_1_CTG2",
   "chr19_GL383574v1_alt": "CHR_HSCHR19_1_CTG3_1",
   "chr19_GL383575v2_alt": "CHR_HSCHR19_2_CTG2",
   "chr19_GL383576v1_alt": "CHR_HSCHR19_3_CTG2",
   "chr19_GL949746v1_alt": "CHR_HSCHR19LRC_COX1_CTG3_1",
   "chr19_GL949747v2_alt": "CHR_HSCHR19LRC_COX2_CTG3_1",
   "chr19_GL949748v2_alt": "CHR_HSCHR19LRC_LRC_I_CTG3_1",
   "chr19_GL949749v2_alt": "CHR_HSCHR19LRC_LRC_J_CTG3_1",
   "chr19_GL949750v2_alt": "CHR_HSCHR19LRC_LRC_S_CTG3_1",
   "chr19_GL949751v2_alt": "CHR_HSCHR19LRC_LRC_T_CTG3_1",
   "chr19_GL949752v1_alt": "CHR_HSCHR19LRC_PGF1_CTG3_1",
   "chr19_GL949753v2_alt": "CHR_HSCHR19LRC_PGF2_CTG3_1",
   "chr19_KI270865v1_alt": "CHR_HSCHR19_4_CTG2",
   "chr19_KI270866v1_alt": "CHR_HSCHR19_2_CTG3_1",
   "chr19_KI270867v1_alt": "CHR_HSCHR19_3_CTG3_1",
   "chr19_KI270868v1_alt": "CHR_HSCHR19_5_CTG2",
   "chr19_KI270882v1_alt": "CHR_HSCHR19KIR_FH15_B_HAP_CTG3_1",
   "chr19_KI270883v1_alt": "CHR_HSCHR19KIR_G085_A_HAP_CTG3_1",
   "chr19_KI270884v1_alt": "CHR_HSCHR19KIR_G085_BA1_HAP_CTG3_1",
   "chr19_KI270885v1_alt": "CHR_HSCHR19KIR_G248_A_HAP_CTG3_1",
   "chr19_KI270886v1_alt": "CHR_HSCHR19KIR_G248_BA2_HAP_CTG3_1",
   "chr19_KI270887v1_alt": "CHR_HSCHR19KIR_GRC212_AB_HAP_CTG3_1",
   "chr19_KI270888v1_alt": "CHR_HSCHR19KIR_GRC212_BA1_HAP_CTG3_1",
   "chr19_KI270889v1_alt": "CHR_HSCHR19KIR_LUCE_A_HAP_CTG3_1",
   "chr19_KI270890v1_alt": "CHR_HSCHR19KIR_LUCE_BDEL_HAP_CTG3_1",
   "chr19_KI270891v1_alt": "CHR_HSCHR19KIR_RSH_A_HAP_CTG3_1",
   "chr19_KI270914v1_alt": "CHR_HSCHR19KIR_RSH_BA2_HAP_CTG3_1",
   "chr19_KI270915v1_alt": "CHR_HSCHR19KIR_T7526_A_HAP_CTG3_1",
   "chr19_KI270916v1_alt": "CHR_HSCHR19KIR_T7526_BDEL_HAP_CTG3_1",
   "chr19_KI270917v1_alt": "CHR_HSCHR19KIR_ABC08_A1_HAP_CTG3_1",
   "chr19_KI270918v1_alt": "CHR_HSCHR19KIR_ABC08_AB_HAP_C_P_CTG3_1",
   "chr19_KI270919v1_alt": "CHR_HSCHR19KIR_ABC08_AB_HAP_T_P_CTG3_1",
   "chr19_KI270920v1_alt": "CHR_HSCHR19KIR_FH05_A_HAP_CTG3_1",
   "chr19_KI270921v1_alt": "CHR_HSCHR19KIR_FH05_B_HAP_CTG3_1",
   "chr19_KI270922v1_alt": "CHR_HSCHR19KIR_FH06_A_HAP_CTG3_1",
   "chr19_KI270923v1_alt": "CHR_HSCHR19KIR_FH06_BA1_HAP_CTG3_1",
   "chr19_KI270929v1_alt": "CHR_HSCHR19KIR_FH08_A_HAP_CTG3_1",
   "chr19_KI270930v1_alt": "CHR_HSCHR19KIR_FH08_BAX_HAP_CTG3_1",
   "chr19_KI270931v1_alt": "CHR_HSCHR19KIR_FH13_A_HAP_CTG3_1",
   "chr19_KI270932v1_alt": "CHR_HSCHR19KIR_FH13_BA2_HAP_CTG3_1",
   "chr19_KI270933v1_alt": "CHR_HSCHR19KIR_FH15_A_HAP_CTG3_1",
   "chr19_KI270938v1_alt": "CHR_HSCHR19_4_CTG3_1",
   "chr1_GL383518v1_alt": "CHR_HSCHR1_1_CTG31",
   "chr1_GL383519v1_alt": "CHR_HSCHR1_2_CTG31",
   "chr1_GL383520v2_alt": "CHR_HSCHR1_3_CTG31",
   "chr1_KI270706v1_random": "KI270706.1",
   "chr1_KI270707v1_random": "KI270707.1",
   "chr1_KI270708v1_random": "KI270708.1",
   "chr1_KI270709v1_random": "KI270709.1",
   "chr1_KI270710v1_random": "KI270710.1",
   "chr1_KI270711v1_random": "KI270711.1",
   "chr1_KI270712v1_random": "KI270712.1",
   "chr1_KI270713v1_random": "KI270713.1",
   "chr1_KI270714v1_random": "KI270714.1",
   "chr1_KI270759v1_alt": "CHR_HSCHR1_1_CTG32_1",
   "chr1_KI270760v1_alt": "CHR_HSCHR1_1_CTG11",
   "chr1_KI270761v1_alt": "CHR_HSCHR1_2_CTG32_1",
   "chr1_KI270762v1_alt": "CHR_HSCHR1_1_CTG3",
   "chr1_KI270763v1_alt": "CHR_HSCHR1_3_CTG32_1",
   "chr1_KI270764v1_alt": "CHR_HSCHR1_4_CTG32_1",
   "chr1_KI270765v1_alt": "CHR_HSCHR1_4_CTG31",
   "chr1_KI270766v1_alt": "CHR_HSCHR1_2_CTG3",
   "chr1_KI270892v1_alt": "CHR_HSCHR1_ALT2_1_CTG32_1",
   "chr2": "2",
   "chr20": "20",
   "chr20_GL383577v2_alt": "CHR_HSCHR20_1_CTG1",
   "chr20_KI270869v1_alt": "CHR_HSCHR20_1_CTG2",
   "chr20_KI270870v1_alt": "CHR_HSCHR20_1_CTG3",
   "chr20_KI270871v1_alt": "CHR_HSCHR20_1_CTG4",
   "chr21": "21",
   "chr21_GL383578v2_alt": "CHR_HSCHR21_1_CTG1_1",
   "chr21_GL383579v2_alt": "CHR_HSCHR21_2_CTG1_1",
   "chr21_GL383580v2_alt": "CHR_HSCHR21_3_CTG1_1",
   "chr21_GL383581v2_alt": "CHR_HSCHR21_4_CTG1_1",
   "chr21_KI270872v1_alt": "CHR_HSCHR21_5_CTG2",
   "chr21_KI270873v1_alt": "CHR_HSCHR21_6_CTG1_1",
   "chr21_KI270874v1_alt": "CHR_HSCHR21_8_CTG1_1",
   "chr22": "22",
   "chr22_GL383582v2_alt": "CHR_HSCHR22_1_CTG1",
   "chr22_GL383583v2_alt": "CHR_HSCHR22_1_CTG2",
   "chr22_KB663609v1_alt": "CHR_HSCHR22_2_CTG1",
   "chr22_KI270731v1_random": "KI270731.1",
   "chr22_KI270732v1_random": "KI270732.1",
   "chr22_KI270733v1_random": "KI270733.1",
   "chr22_KI270734v1_random": "KI270734.1",
   "chr22_KI270735v1_random": "KI270735.1",
   "chr22_KI270736v1_random": "KI270736.1",
   "chr22_KI270737v1_random": "KI270737.1",
   "chr22_KI270738v1_random": "KI270738.1",
   "chr22_KI270739v1_random": "KI270739.1",
   "chr22_KI270875v1_alt": "CHR_HSCHR22_1_CTG3",
   "chr22_KI270876v1_alt": "CHR_HSCHR22_1_CTG4",
   "chr22_KI270877v1_alt": "CHR_HSCHR22_1_CTG5",
   "chr22_KI270878v1_alt": "CHR_HSCHR22_1_CTG6",
   "chr22_KI270879v1_alt": "CHR_HSCHR22_1_CTG7",
   "chr22_KI270928v1_alt": "CHR_HSCHR22_3_CTG1",
   "chr2_GL383521v1_alt": "CHR_HSCHR2_1_CTG5",
   "chr2_GL383522v1_alt": "CHR_HSCHR2_1_CTG7_2",
   "chr2_GL582966v2_alt": "CHR_HSCHR2_2_CTG7_2",
   "chr2_KI270715v1_random": "KI270715.1",
   "chr2_KI270716v1_random": "KI270716.1",
   "chr2_KI270767v1_alt": "CHR_HSCHR2_1_CTG15",
   "chr2_KI270768v1_alt": "CHR_HSCHR2_3_CTG7_2",
   "chr2_KI270769v1_alt": "CHR_HSCHR2_1_CTG1",
   "chr2_KI270770v1_alt": "CHR_HSCHR2_2_CTG1",
   "chr2_KI270771v1_alt": "CHR_HSCHR2_4_CTG7_2",
   "chr2_KI270772v1_alt": "CHR_HSCHR2_1_CTG7",
   "chr2_KI270773v1_alt": "CHR_HSCHR2_3_CTG1",
   "chr2_KI270774v1_alt": "CHR_HSCHR2_4_CTG1",
   "chr2_KI270775v1_alt": "CHR_HSCHR2_5_CTG7_2",
   "chr2_KI270776v1_alt": "CHR_HSCHR2_3_CTG15",
   "chr2_KI270893v1_alt": "CHR_HSCHR2_2_CTG15",
   "chr2_KI270894v1_alt": "CHR_HSCHR2_2_CTG7",
   "chr3": "3",
   "chr3_GL000221v1_random": "CHR_HSCHR3UN_CTG2",
   "chr3_GL383526v1_alt": "CHR_HSCHR3_1_CTG2_1",
   "chr3_JH636055v2_alt": "CHR_HSCHR3_1_CTG1",
   "chr3_KI270777v1_alt": "CHR_HSCHR3_2_CTG2_1",
   "chr3_KI270778v1_alt": "CHR_HSCHR3_3_CTG2_1",
   "chr3_KI270779v1_alt": "CHR_HSCHR3_1_CTG3",
   "chr3_KI270780v1_alt": "CHR_HSCHR3_4_CTG2_1",
   "chr3_KI270781v1_alt": "CHR_HSCHR3_5_CTG2_1",
   "chr3_KI270782v1_alt": "CHR_HSCHR3_2_CTG3",
   "chr3_KI270783v1_alt": "CHR_HSCHR3_3_CTG1",
   "chr3_KI270784v1_alt": "CHR_HSCHR3_9_CTG3",
   "chr3_KI270895v1_alt": "CHR_HSCHR3_3_CTG3",
   "chr3_KI270924v1_alt": "CHR_HSCHR3_4_CTG3",
   "chr3_KI270934v1_alt": "CHR_HSCHR3_5_CTG3",
   "chr3_KI270935v1_alt": "CHR_HSCHR3_6_CTG3",
   "chr3_KI270936v1_alt": "CHR_HSCHR3_7_CTG3",
   "chr3_KI270937v1_alt": "CHR_HSCHR3_8_CTG3",
   "chr4": "4",
   "chr4_GL000008v2_random": "GL000008.2",
   "chr4_GL000257v2_alt": "CHR_HSCHR4_1_CTG9",
   "chr4_GL383527v1_alt": "CHR_HSCHR4_1_CTG12",
   "chr4_GL383528v1_alt": "CHR_HSCHR4_1_CTG6",
   "chr4_KI270785v1_alt": "CHR_HSCHR4_2_CTG12",
   "chr4_KI270786v1_alt": "CHR_HSCHR4_3_CTG12",
   "chr4_KI270787v1_alt": "CHR_HSCHR4_1_CTG8_1",
   "chr4_KI270788v1_alt": "CHR_HSCHR4_4_CTG12",
   "chr4_KI270789v1_alt": "CHR_HSCHR4_5_CTG12",
   "chr4_KI270790v1_alt": "CHR_HSCHR4_1_CTG4",
   "chr4_KI270896v1_alt": "CHR_HSCHR4_6_CTG12",
   "chr4_KI270925v1_alt": "CHR_HSCHR4_7_CTG12",
   "chr5": "5",
   "chr5_GL000208v1_random": "GL000208.1",
   "chr5_GL339449v2_alt": "CHR_HSCHR5_2_CTG1_1",
   "chr5_GL383530v1_alt": "CHR_HSCHR5_3_CTG1_1",
   "chr5_GL383531v1_alt": "CHR_HSCHR5_1_CTG5",
   "chr5_GL383532v1_alt": "CHR_HSCHR5_1_CTG1",
   "chr5_GL949742v1_alt": "CHR_HSCHR5_2_CTG1",
   "chr5_KI270791v1_alt": "CHR_HSCHR5_3_CTG1",
   "chr5_KI270792v1_alt": "CHR_HSCHR5_4_CTG1",
   "chr5_KI270793v1_alt": "CHR_HSCHR5_5_CTG1",
   "chr5_KI270794v1_alt": "CHR_HSCHR5_6_CTG1",
   "chr5_KI270795v1_alt": "CHR_HSCHR5_2_CTG5",
   "chr5_KI270796v1_alt": "CHR_HSCHR5_4_CTG1_1",
   "chr5_KI270897v1_alt": "CHR_HSCHR5_1_CTG1_1",
   "chr5_KI270898v1_alt": "CHR_HSCHR5_3_CTG5",
   "chr6": "6",
   "chr6_GL000250v2_alt": "CHR_HSCHR6_MHC_APD_CTG1",
   "chr6_GL000251v2_alt": "CHR_HSCHR6_MHC_COX_CTG1",
   "chr6_GL000252v2_alt": "CHR_HSCHR6_MHC_DBB_CTG1",
   "chr6_GL000253v2_alt": "CHR_HSCHR6_MHC_MANN_CTG1",
   "chr6_GL000254v2_alt": "CHR_HSCHR6_MHC_MCF_CTG1",
   "chr6_GL000255v2_alt": "CHR_HSCHR6_MHC_QBL_CTG1",
   "chr6_GL000256v2_alt": "CHR_HSCHR6_MHC_SSTO_CTG1",
   "chr6_GL383533v1_alt": "CHR_HSCHR6_1_CTG2",
   "chr6_KB021644v2_alt": "CHR_HSCHR6_1_CTG3",
   "chr6_KI270758v1_alt": "CHR_HSCHR6_8_CTG1",
   "chr6_KI270797v1_alt": "CHR_HSCHR6_1_CTG4",
   "chr6_KI270798v1_alt": "CHR_HSCHR6_1_CTG5",
   "chr6_KI270799v1_alt": "CHR_HSCHR6_1_CTG6",
   "chr6_KI270800v1_alt": "CHR_HSCHR6_1_CTG7",
   "chr6_KI270801v1_alt": "CHR_HSCHR6_1_CTG8",
   "chr6_KI270802v1_alt": "CHR_HSCHR6_1_CTG9",
   "chr7": "7",
   "chr7_GL383534v2_alt": "CHR_HSCHR7_1_CTG6",
   "chr7_KI270803v1_alt": "CHR_HSCHR7_2_CTG6",
   "chr7_KI270804v1_alt": "CHR_HSCHR7_1_CTG1",
   "chr7_KI270805v1_alt": "CHR_HSCHR7_1_CTG7",
   "chr7_KI270806v1_alt": "CHR_HSCHR7_1_CTG4_4",
   "chr7_KI270807v1_alt": "CHR_HSCHR7_2_CTG7",
   "chr7_KI270808v1_alt": "CHR_HSCHR7_3_CTG6",
   "chr7_KI270809v1_alt": "CHR_HSCHR7_2_CTG4_4",
   "chr7_KI270899v1_alt": "CHR_HSCHR7_2_CTG1",
   "chr8": "8",
   "chr8_KI270810v1_alt": "CHR_HSCHR8_1_CTG7",
   "chr8_KI270811v1_alt": "CHR_HSCHR8_1_CTG1",
   "chr8_KI270812v1_alt": "CHR_HSCHR8_2_CTG1",
   "chr8_KI270813v1_alt": "CHR_HSCHR8_3_CTG1",
   "chr8_KI270814v1_alt": "CHR_HSCHR8_1_CTG6",
   "chr8_KI270815v1_alt": "CHR_HSCHR8_2_CTG7",
   "chr8_KI270816v1_alt": "CHR_HSCHR8_3_CTG7",
   "chr8_KI270817v1_alt": "CHR_HSCHR8_4_CTG7",
   "chr8_KI270818v1_alt": "CHR_HSCHR8_4_CTG1",
   "chr8_KI270819v1_alt": "CHR_HSCHR8_5_CTG7",
   "chr8_KI270820v1_alt": "CHR_HSCHR8_6_CTG7",
   "chr8_KI270821v1_alt": "CHR_HSCHR8_8_CTG1",
   "chr8_KI270822v1_alt": "CHR_HSCHR8_9_CTG1",
   "chr8_KI270900v1_alt": "CHR_HSCHR8_5_CTG1",
   "chr8_KI270901v1_alt": "CHR_HSCHR8_6_CTG1",
   "chr8_KI270926v1_alt": "CHR_HSCHR8_7_CTG1",
   "chr9": "9",
   "chr9_GL383539v1_alt": "CHR_HSCHR9_1_CTG1",
   "chr9_GL383540v1_alt": "CHR_HSCHR9_1_CTG2",
   "chr9_GL383541v1_alt": "CHR_HSCHR9_1_CTG3",
   "chr9_GL383542v1_alt": "CHR_HSCHR9_1_CTG4",
   "chr9_KI270717v1_random": "KI270717.1",
   "chr9_KI270718v1_random": "KI270718.1",
   "chr9_KI270719v1_random": "KI270719.1",
   "chr9_KI270720v1_random": "KI270720.1",
   "chr9_KI270823v1_alt": "CHR_HSCHR9_1_CTG5",
   "chrM": "MT",
   "chrUn_GL000195v1": "GL000195.1",
   "chrUn_GL000213v1": "GL000213.1",
   "chrUn_GL000214v1": "GL000214.1",
   "chrUn_GL000216v2": "GL000216.2",
   "chrUn_GL000218v1": "GL000218.1",
   "chrUn_GL000219v1": "GL000219.1",
   "chrUn_GL000220v1": "GL000220.1",
   "chrUn_GL000224v1": "GL000224.1",
   "chrUn_GL000226v1": "GL000226.1",
   "chrUn_KI270302v1": "KI270302.1",
   "chrUn_KI270303v1": "KI270303.1",
   "chrUn_KI270304v1": "KI270304.1",
   "chrUn_KI270305v1": "KI270305.1",
   "chrUn_KI270310v1": "KI270310.1",
   "chrUn_KI270311v1": "KI270311.1",
   "chrUn_KI270312v1": "KI270312.1",
   "chrUn_KI270315v1": "KI270315.1",
   "chrUn_KI270316v1": "KI270316.1",
   "chrUn_KI270317v1": "KI270317.1",
   "chrUn_KI270320v1": "KI270320.1",
   "chrUn_KI270322v1": "KI270322.1",
   "chrUn_KI270329v1": "KI270329.1",
   "chrUn_KI270330v1": "KI270330.1",
   "chrUn_KI270333v1": "KI270333.1",
   "chrUn_KI270334v1": "KI270334.1",
   "chrUn_KI270335v1": "KI270335.1",
   "chrUn_KI270336v1": "KI270336.1",
   "chrUn_KI270337v1": "KI270337.1",
   "chrUn_KI270338v1": "KI270338.1",
   "chrUn_KI270340v1": "KI270340.1",
   "chrUn_KI270362v1": "KI270362.1",
   "chrUn_KI270363v1": "KI270363.1",
   "chrUn_KI270364v1": "KI270364.1",
   "chrUn_KI270366v1": "KI270366.1",
   "chrUn_KI270371v1": "KI270371.1",
   "chrUn_KI270372v1": "KI270372.1",
   "chrUn_KI270373v1": "KI270373.1",
   "chrUn_KI270374v1": "KI270374.1",
   "chrUn_KI270375v1": "KI270375.1",
   "chrUn_KI270376v1": "KI270376.1",
   "chrUn_KI270378v1": "KI270378.1",
   "chrUn_KI270379v1": "KI270379.1",
   "chrUn_KI270381v1": "KI270381.1",
   "chrUn_KI270382v1": "KI270382.1",
   "chrUn_KI270383v1": "KI270383.1",
   "chrUn_KI270384v1": "KI270384.1",
   "chrUn_KI270385v1": "KI270385.1",
   "chrUn_KI270386v1": "KI270386.1",
   "chrUn_KI270387v1": "KI270387.1",
   "chrUn_KI270388v1": "KI270388.1",
   "chrUn_KI270389v1": "KI270389.1",
   "chrUn_KI270390v1": "KI270390.1",
   "chrUn_KI270391v1": "KI270391.1",
   "chrUn_KI270392v1": "KI270392.1",
   "chrUn_KI270393v1": "KI270393.1",
   "chrUn_KI270394v1": "KI270394.1",
   "chrUn_KI270395v1": "KI270395.1",
   "chrUn_KI270396v1": "KI270396.1",
   "chrUn_KI270411v1": "KI270411.1",
   "chrUn_KI270412v1": "KI270412.1",
   "chrUn_KI270414v1": "KI270414.1",
   "chrUn_KI270417v1": "KI270417.1",
   "chrUn_KI270418v1": "KI270418.1",
   "chrUn_KI270419v1": "KI270419.1",
   "chrUn_KI270420v1": "KI270420.1",
   "chrUn_KI270422v1": "KI270422.1",
   "chrUn_KI270423v1": "KI270423.1",
   "chrUn_KI270424v1": "KI270424.1",
   "chrUn_KI270425v1": "KI270425.1",
   "chrUn_KI270429v1": "KI270429.1",
   "chrUn_KI270435v1": "KI270435.1",
   "chrUn_KI270438v1": "KI270438.1",
   "chrUn_KI270442v1": "KI270442.1",
   "chrUn_KI270448v1": "KI270448.1",
   "chrUn_KI270465v1": "KI270465.1",
   "chrUn_KI270466v1": "KI270466.1",
   "chrUn_KI270467v1": "KI270467.1",
   "chrUn_KI270468v1": "KI270468.1",
   "chrUn_KI270507v1": "KI270507.1",
   "chrUn_KI270508v1": "KI270508.1",
   "chrUn_KI270509v1": "KI270509.1",
   "chrUn_KI270510v1": "KI270510.1",
   "chrUn_KI270511v1": "KI270511.1",
   "chrUn_KI270512v1": "KI270512.1",
   "chrUn_KI270515v1": "KI270515.1",
   "chrUn_KI270516v1": "KI270516.1",
   "chrUn_KI270517v1": "KI270517.1",
   "chrUn_KI270518v1": "KI270518.1",
   "chrUn_KI270519v1": "KI270519.1",
   "chrUn_KI270521v1": "KI270521.1",
   "chrUn_KI270522v1": "KI270522.1",
   "chrUn_KI270528v1": "KI270528.1",
   "chrUn_KI270529v1": "KI270529.1",
   "chrUn_KI270530v1": "KI270530.1",
   "chrUn_KI270538v1": "KI270538.1",
   "chrUn_KI270539v1": "KI270539.1",
   "chrUn_KI270544v1": "KI270544.1",
   "chrUn_KI270548v1": "KI270548.1",
   "chrUn_KI270579v1": "KI270579.1",
   "chrUn_KI270580v1": "KI270580.1",
   "chrUn_KI270581v1": "KI270581.1",
   "chrUn_KI270582v1": "KI270582.1",
   "chrUn_KI270583v1": "KI270583.1",
   "chrUn_KI270584v1": "KI270584.1",
   "chrUn_KI270587v1": "KI270587.1",
   "chrUn_KI270588v1": "KI270588.1",
   "chrUn_KI270589v1": "KI270589.1",
   "chrUn_KI270590v1": "KI270590.1",
   "chrUn_KI270591v1": "KI270591.1",
   "chrUn_KI270593v1": "KI270593.1",
   "chrUn_KI270741v1": "KI270741.1",
   "chrUn_KI270742v1": "KI270742.1",
   "chrUn_KI270743v1": "KI270743.1",
   "chrUn_KI270744v1": "KI270744.1",
   "chrUn_KI270745v1": "KI270745.1",
   "chrUn_KI270746v1": "KI270746.1",
   "chrUn_KI270747v1": "KI270747.1",
   "chrUn_KI270748v1": "KI270748.1",
   "chrUn_KI270749v1": "KI270749.1",
   "chrUn_KI270750v1": "KI270750.1",
   "chrUn_KI270751v1": "KI270751.1",
   "chrUn_KI270752v1": "KI270752.1",
   "chrUn_KI270753v1": "KI270753.1",
   "chrUn_KI270754v1": "KI270754.1",
   "chrUn_KI270755v1": "KI270755.1",
   "chrUn_KI270756v1": "KI270756.1",
   "chrUn_KI270757v1": "KI270757.1",
   "chrX": "X",
   "chrX_KI270880v1_alt": "CHR_HSCHRX_1_CTG3",
   "chrX_KI270881v1_alt": "CHR_HSCHRX_2_CTG12",
   "chrX_KI270913v1_alt": "CHR_HSCHRX_2_CTG3",
   "chrY": "Y",
   "chrY_KI270740v1_random": "KI270740.1"
}

hg38_ucsc2ensembl_patches= { 
   "chr1_KQ031383v1_fix": "CHR_HG1342_HG2282_PATCH",
   "chr1_KQ983255v1_alt": "CHR_HSCHR1_5_CTG3",
   "chr1_KN538361v1_fix": "CHR_HG2095_PATCH",
   "chr1_KQ458383v1_alt": "CHR_HSCHR1_4_CTG3",
   "chr1_KN196473v1_fix": "CHR_HG2058_PATCH",
   "chr1_KZ208904v1_alt": "CHR_HSCHR1_8_CTG3",
   "chr1_KN196472v1_fix": "CHR_HG986_PATCH",
   "chr1_KQ458382v1_alt": "CHR_HSCHR1_3_CTG3",
   "chr1_KV880763v1_alt": "CHR_HSCHR1_6_CTG3",
   "chr1_KZ208905v1_alt": "CHR_HSCHR1_9_CTG3",
   "chr1_KN196474v1_fix": "CHR_HG2104_PATCH",
   "chr1_KN538360v1_fix": "CHR_HG1832_PATCH",
   "chr1_KZ208906v1_fix": "CHR_HG2002_PATCH",
   "chr1_KQ458384v1_alt": "CHR_HSCHR1_5_CTG32_1",
   "chr2_KQ031384v1_fix": "CHR_HG2290_PATCH",
   "chr2_KQ983256v1_alt": "CHR_HSCHR2_6_CTG7_2",
   "chr2_KZ208907v1_alt": "CHR_HSCHR2_7_CTG7_2",
   "chr2_KZ208908v1_alt": "CHR_HSCHR2_8_CTG7_2",
   "chr2_KN538362v1_fix": "CHR_HG2233_PATCH",
   "chr2_KN538363v1_fix": "CHR_HG2232_PATCH",
   "chr3_KN196475v1_fix": "CHR_HG2066_PATCH",
   "chr3_KN538364v1_fix": "CHR_HG126_PATCH",
   "chr3_KQ031385v1_fix": "CHR_HG2235_PATCH",
   "chr3_KV766192v1_fix": "CHR_HG2236_PATCH",
   "chr3_KZ208909v1_alt": "CHR_HSCHR3_4_CTG1",
   "chr3_KN196476v1_fix": "CHR_HG2022_PATCH",
   "chr3_KQ031386v1_fix": "CHR_HG2237_PATCH",
   "chr4_KQ090013v1_alt": "CHR_HSCHR4_2_CTG4",
   "chr4_KQ090014v1_alt": "CHR_HSCHR4_8_CTG12",
   "chr4_KQ090015v1_alt": "CHR_HSCHR4_9_CTG12",
   "chr4_KV766193v1_alt": "CHR_HSCHR4_12_CTG12",
   "chr4_KQ983257v1_fix": "CHR_HG2023_PATCH",
   "chr4_KQ983258v1_alt": "CHR_HSCHR4_11_CTG12",
   "chr5_KN196477v1_alt": "CHR_HSCHR5_7_CTG1",
   "chr5_KV575243v1_alt": "CHR_HSCHR5_8_CTG1",
   "chr5_KZ208910v1_alt": "CHR_HSCHR5_9_CTG1",
   "chr5_KV575244v1_fix": "CHR_HG30_PATCH",
   "chr6_KZ208911v1_fix": "CHR_HG2057_PATCH",
   "chr6_KQ090017v1_alt": "CHR_HSCHR6_1_CTG10",
   "chr6_KN196478v1_fix": "CHR_HG2128_PATCH",
   "chr6_KQ031387v1_fix": "CHR_HG1651_PATCH",
   "chr6_KQ090016v1_fix": "CHR_HG2072_PATCH",
   "chr6_KV766194v1_fix": "CHR_HG2121_PATCH",
   "chr7_KV880764v1_fix": "CHR_HG2088_PATCH",
   "chr7_KV880765v1_fix": "CHR_HG2266_PATCH",
   "chr7_KZ208912v1_fix": "CHR_HG708_PATCH",
   "chr7_KZ208913v1_alt": "CHR_HSCHR7_3_CTG4_4",
   "chr7_KQ031388v1_fix": "CHR_HG2239_PATCH",
   "chr8_KV880766v1_fix": "CHR_HG2067_PATCH",
   "chr8_KV880767v1_fix": "CHR_HG2068_PATCH",
   "chr8_KZ208914v1_fix": "CHR_HG2419_PATCH",
   "chr8_KZ208915v1_fix": "CHR_HG76_PATCH",
   "chr9_KQ090018v1_alt": "CHR_HSCHR9_1_CTG6",
   "chr9_KQ090019v1_alt": "CHR_HSCHR9_1_CTG7",
   "chr9_KN196479v1_fix": "CHR_HG2030_PATCH",
   "chr10_KN538367v1_fix": "CHR_HG2244_HG2245_PATCH",
   "chr10_KQ090020v1_alt": "CHR_HSCHR10_1_CTG6",
   "chr10_KN196480v1_fix": "CHR_HG2191_PATCH",
   "chr10_KN538365v1_fix": "CHR_HG2241_PATCH",
   "chr10_KN538366v1_fix": "CHR_HG2242_HG2243_PATCH",
   "chr10_KQ090021v1_fix": "CHR_HG2334_PATCH",
   "chr11_KQ759759v1_fix": "CHR_HG107_PATCH",
   "chr11_KN538368v1_alt": "CHR_HSCHR11_1_CTG1_2",
   "chr11_KN196481v1_fix": "CHR_HG2217_PATCH",
   "chr11_KQ090022v1_fix": "CHR_HG2116_PATCH",
   "chr11_KV766195v1_fix": "CHR_HG1708_PATCH",
   "chr12_KQ090023v1_alt": "CHR_HSCHR12_2_CTG1",
   "chr12_KN196482v1_fix": "CHR_HG23_PATCH",
   "chr12_KN538369v1_fix": "CHR_HG1362_PATCH",
   "chr12_KZ208916v1_fix": "CHR_HG1815_PATCH",
   "chr12_KZ208918v1_alt": "CHR_HSCHR12_8_CTG2_1",
   "chr12_KN538370v1_fix": "CHR_HG2247_PATCH",
   "chr12_KQ759760v1_fix": "CHR_HG2063_PATCH",
   "chr12_KZ208917v1_fix": "CHR_HG2047_PATCH",
   "chr13_KN538372v1_fix": "CHR_HG2291_PATCH",
   "chr13_KQ090024v1_alt": "CHR_HSCHR13_1_CTG7",
   "chr13_KN196483v1_fix": "CHR_HG2216_PATCH",
   "chr13_KN538373v1_fix": "CHR_HG2249_PATCH",
   "chr13_KQ090025v1_alt": "CHR_HSCHR13_1_CTG8",
   "chr13_KN538371v1_fix": "CHR_HG2288_HG2289_PATCH",
   "chr14_KZ208920v1_fix": "CHR_HG1_PATCH",
   "chr14_KZ208919v1_alt": "CHR_HSCHR14_8_CTG1",
   "chr15_KN538374v1_fix": "CHR_HG2139_PATCH",
   "chr15_KQ031389v1_alt": "CHR_HSCHR15_6_CTG8",
   "chr16_KQ090026v1_alt": "CHR_HSCHR16_5_CTG1",
   "chr16_KV880768v1_fix": "CHR_HG926_PATCH",
   "chr16_KQ031390v1_alt": "CHR_HSCHR16_3_CTG3_1",
   "chr16_KQ090027v1_alt": "CHR_HSCHR16_4_CTG3_1",
   "chr16_KZ208921v1_alt": "CHR_HSCHR16_5_CTG3_1",
   "chr17_KV575245v1_fix": "CHR_HG2046_PATCH",
   "chr17_KV766196v1_fix": "CHR_HG2285_HG106_HG2252_PATCH",
   "chr17_KV766197v1_alt": "CHR_HSCHR17_11_CTG4",
   "chr17_KV766198v1_alt": "CHR_HSCHR17_3_CTG1",
   "chr18_KQ458385v1_alt": "CHR_HSCHR18_5_CTG1_1",
   "chr18_KQ090028v1_fix": "CHR_HG2213_PATCH",
   "chr18_KZ208922v1_fix": "CHR_HG2442_PATCH",
   "chr19_KN196484v1_fix": "CHR_HG2021_PATCH",
   "chr19_KQ458386v1_fix": "CHR_HG26_PATCH",
   "chr19_KV575246v1_alt": "CHR_HSCHR19KIR_0019-4656-A_CTG3_1",
   "chr19_KV575247v1_alt": "CHR_HSCHR19KIR_CA01-TA01_1_CTG3_1",
   "chr19_KV575248v1_alt": "CHR_HSCHR19KIR_CA01-TA01_2_CTG3_1",
   "chr19_KV575249v1_alt": "CHR_HSCHR19KIR_CA01-TB04_CTG3_1",
   "chr19_KV575250v1_alt": "CHR_HSCHR19KIR_CA01-TB01_CTG3_1",
   "chr19_KV575251v1_alt": "CHR_HSCHR19KIR_HG2394_CTG3_1",
   "chr19_KV575252v1_alt": "CHR_HSCHR19KIR_502960008-2_CTG3_1",
   "chr19_KV575253v1_alt": "CHR_HSCHR19KIR_502960008-1_CTG3_1",
   "chr19_KV575254v1_alt": "CHR_HSCHR19KIR_0010-5217-AB_CTG3_1",
   "chr19_KV575255v1_alt": "CHR_HSCHR19KIR_7191059-1_CTG3_1",
   "chr19_KV575256v1_alt": "CHR_HSCHR19KIR_0019-4656-B_CTG3_1",
   "chr19_KV575257v1_alt": "CHR_HSCHR19KIR_CA04_CTG3_1",
   "chr19_KV575258v1_alt": "CHR_HSCHR19KIR_HG2393_CTG3_1",
   "chr19_KV575259v1_alt": "CHR_HSCHR19KIR_7191059-2_CTG3_1",
   "chr19_KV575260v1_alt": "CHR_HSCHR19KIR_HG2396_CTG3_1",
   "chr22_KN196485v1_alt": "CHR_HSCHR22_4_CTG1",
   "chr22_KN196486v1_alt": "CHR_HSCHR22_5_CTG1",
   "chr22_KQ458387v1_alt": "CHR_HSCHR22_6_CTG1",
   "chr22_KQ458388v1_alt": "CHR_HSCHR22_7_CTG1",
   "chr22_KQ759761v1_alt": "CHR_HSCHR22_8_CTG1",
   "chr22_KQ759762v1_fix": "CHR_HG1311_PATCH",
   "chrX_KV766199v1_alt": "CHR_HSCHRX_3_CTG7",
   "chrY_KN196487v1_fix": "CHR_HG2062_PATCH",
   "chrY_KZ208923v1_fix": "CHR_HG1531_PATCH",
   "chrY_KZ208924v1_fix": "CHR_HG1535_PATCH"
}


hg38_ensembl2ucsc = {v:k for k,v in hg38_ucsc2ensembl.items()}
hg38_ensembl2ucsc_patches = {v:k for k,v in hg38_ucsc2ensembl_patches.items()}



mm10_ucsc2ensembl = {
   "chr15": "15",
   "chrUn_JH584304": "JH584304.1",
   "chr12": "12",
   "chr13": "13",
   "chr11": "11",
   "chr9": "9",
   "chr14": "14",
   "chr8": "8",
   "chr10": "10",
   "chr7": "7",
   "chr4_JH584292_random": "JH584292.1",
   "chr6": "6",
   "chr5": "5",
   "chr1_GL456212_random": "GL456212.1",
   "chrY_JH584302_random": "JH584302.1",
   "chr4": "4",
   "chrY_JH584303_random": "JH584303.1",
   "chr3": "3",
   "chrM": "MT",
   "chr1_GL456210_random": "GL456210.1",
   "chrX": "X",
   "chr7_GL456219_random": "GL456219.1",
   "chr2": "2",
   "chrY_JH584300_random": "JH584300.1",
   "chr5_JH584298_random": "JH584298.1",
   "chr4_JH584294_random": "JH584294.1",
   "chr1": "1",
   "chr5_GL456354_random": "GL456354.1",
   "chr4_JH584295_random": "JH584295.1",
   "chr5_JH584296_random": "JH584296.1",
   "chrUn_GL456368": "GL456368.1",
   "chr5_JH584297_random": "JH584297.1",
   "chr1_GL456221_random": "GL456221.1",
   "chr4_JH584293_random": "JH584293.1",
   "chrUn_GL456396": "GL456396.1",
   "chr4_GL456350_random": "GL456350.1",
   "chrUn_GL456359": "GL456359.1",
   "chrUn_GL456382": "GL456382.1",
   "chrUn_GL456392": "GL456392.1",
   "chr1_GL456211_random": "GL456211.1",
   "chrUn_GL456394": "GL456394.1",
   "chrUn_GL456390": "GL456390.1",
   "chrUn_GL456387": "GL456387.1",
   "chrUn_GL456381": "GL456381.1",
   "chrY_JH584301_random": "JH584301.1",
   "chrUn_GL456370": "GL456370.1",
   "chrUn_GL456372": "GL456372.1",
   "chrUn_GL456389": "GL456389.1",
   "chrUn_GL456378": "GL456378.1",
   "chrUn_GL456360": "GL456360.1",
   "chrX_GL456233_random": "GL456233.1",
   "chrUn_GL456385": "GL456385.1",
   "chrUn_GL456383": "GL456383.1",
   "chr1_GL456213_random": "GL456213.1",
   "chrUn_GL456239": "GL456239.1",
   "chrUn_GL456367": "GL456367.1",
   "chrUn_GL456366": "GL456366.1",
   "chrUn_GL456393": "GL456393.1",
   "chr19": "19",
   "chr4_GL456216_random": "GL456216.1",
   "chrUn_GL456379": "GL456379.1",
   "chr18": "18",
   "chrY": "Y",
   "chr17": "17",
   "chr5_JH584299_random": "JH584299.1",
   "chr16": "16"
        }

mm10_ucsc2ensembl_patches= {
   "KK082441.1": "CHR_MMCHR1_CHORI29_IDD5_1",
   "KQ030484.1": "CHR_MG4248_PATCH",
   "JH792826.1": "CHR_MG4136_PATCH",
   "KQ030485.1": "CHR_MG3561_PATCH",
   "KQ030486.1": "CHR_MG3562_PATCH",
   "KQ030487.1": "CHR_MG3609_PATCH",
   "KQ030488.1": "CHR_MG4265_PATCH",
   "KQ030489.1": "CHR_MG4266_PATCH",
   "JH792827.1": "CHR_MG4212_PATCH",
   "KK082442.1": "CHR_MG184_PATCH",
   "JH792828.1": "CHR_MG4151_PATCH",
   "KB469738.3": "CHR_MG132_PATCH",
   "KQ030490.1": "CHR_MG117_PATCH",
   "KQ030491.1": "CHR_MG4264_PATCH",
   "KB469739.1": "CHR_MG3829_PATCH",
   "KB469740.1": "CHR_MG4180_PATCH",
   "KQ030492.1": "CHR_MG4259_PATCH",
   "KQ030493.1": "CHR_MG4261_PATCH",
   "KB469741.1": "CHR_MG3833_PATCH",
   "KB469742.1": "CHR_MG4222_MG3908_PATCH",
   "JH792829.1": "CHR_MG3835_PATCH",
   "JH792830.1": "CHR_MG153_PATCH",
   "KQ030494.1": "CHR_MG4249_PATCH",
   "JH792831.1": "CHR_MG4214_PATCH",
   "KQ030495.1": "CHR_MG3231_PATCH",
   "KQ030496.1": "CHR_MG4254_PATCH",
   "KQ030497.1": "CHR_MG4255_PATCH",
   "JH792832.1": "CHR_MG4209_PATCH",
   "JH792833.1": "CHR_MG4211_PATCH",
   "JH792834.1": "CHR_MG4213_PATCH",
   "GL456079.1": "CHR_129P2/OLAHSD_MMCHR19_CTG1",
   "GL456024.2": "CHR_129S1/SVIMJ_MMCHR2_CTG2",
   "GL456006.1": "CHR_129S1/SVIMJ_MMCHR3_CTG3",
   "GL456007.1": "CHR_129S1/SVIMJ_MMCHR3_CTG2",
   "GL456008.1": "CHR_129S1/SVIMJ_MMCHR3_CTG4",
   "GL456011.1": "CHR_129S1/SVIMJ_MMCHR5_CTG5",
   "GL456025.1": "CHR_129S1/SVIMJ_MMCHR6_CTG1",
   "GL456026.2": "CHR_129S1/SVIMJ_MMCHR6_CTG5",
   "GL456014.1": "CHR_129S1/SVIMJ_MMCHR7_CTG1",
   "GL456017.2": "CHR_129S1/SVIMJ_MMCHR12_CTG1",
   "GL456074.1": "CHR_129S1/SVIMJ_MMCHR12_CTG3",
   "JH584305.1": "CHR_129S1/SVIMJ_MMCHR13_CTG1",
   "GL456019.1": "CHR_129S1/SVIMJ_MMCHR14_CTG3",
   "JH584306.1": "CHR_129S1/SVIMJ_MMCHR16_CTG1",
   "JH584307.1": "CHR_129S1/SVIMJ_MMCHR16_CTG2",
   "JH584308.1": "CHR_129S1/SVIMJ_MMCHR17_CTG3",
   "JH584309.1": "CHR_129S1/SVIMJ_MMCHR17_CTG4",
   "JH590470.1": "CHR_129S1/SVIMJ_MMCHR17_CTG2",
   "GL456031.1": "CHR_129S1/SVIMJ_MMCHRX_CTG10",
   "GL456032.1": "CHR_129S1/SVIMJ_MMCHRX_CTG3",
   "GL456033.2": "CHR_129S1/SVIMJ_MMCHRX_CTG7",
   "GL456013.1": "CHR_129S2/SVPAS_MMCHR7_CTG1",
   "GL455991.1": "CHR_129S6/SVEVTAC_MMCHR1_CTG3",
   "GL455992.2": "CHR_129S6/SVEVTAC_MMCHR1_CTG4",
   "GL455993.1": "CHR_129S6/SVEVTAC_MMCHR1_CTG1",
   "GL455994.1": "CHR_129S6/SVEVTAC_MMCHR4_CTG1",
   "GL455995.1": "CHR_129S6/SVEVTAC_MMCHR5_CTG1",
   "GL455996.1": "CHR_129S6/SVEVTAC_MMCHR8_CTG1",
   "GL455997.1": "CHR_129S6/SVEVTAC_MMCHR8_CTG2",
   "GL455998.1": "CHR_129S6/SVEVTAC_MMCHR11_CTG1",
   "GL455999.2": "CHR_129S6/SVEVTAC_MMCHR13_CTG1",
   "GL456000.1": "CHR_129S6/SVEVTAC_MMCHR15_CTG1",
   "GL456001.2": "CHR_129S6/SVEVTAC_MMCHR16_CTG6",
   "JH584310.1": "CHR_129S6/SVEVTAC_MMCHR16_CTG1",
   "JH584311.1": "CHR_129S6/SVEVTAC_MMCHR16_CTG2",
   "JH584312.1": "CHR_129S6/SVEVTAC_MMCHR16_CTG3",
   "JH584313.1": "CHR_129S6/SVEVTAC_MMCHR16_CTG4",
   "JH584314.1": "CHR_129S6/SVEVTAC_MMCHR16_CTG5",
   "GL456002.2": "CHR_129S6/SVEVTAC_MMCHR17_CTG2",
   "GL456021.2": "CHR_129S6/SVEVTAC_MMCHR17_CTG1",
   "GL456003.2": "CHR_129S6/SVEVTAC_MMCHRX_CTG2",
   "GL456004.1": "CHR_129S6/SVEVTAC_MMCHRX_CTG6",
   "GL456005.1": "CHR_129X1/SVJ_MMCHR1_CTG2",
   "JH584315.1": "CHR_129X1/SVJ_MMCHR1_CTG1",
   "GL456010.1": "CHR_129X1/SVJ_MMCHR4_CTG2",
   "GL456012.2": "CHR_129X1/SVJ_MMCHR6_CTG1",
   "GL456065.1": "CHR_129X1/SVJ_MMCHR6_CTG3",
   "GL456016.1": "CHR_129X1/SVJ_MMCHR11_CTG3",
   "GL456020.1": "CHR_129X1/SVJ_MMCHR14_CTG1",
   "GL456028.2": "CHR_129X1/SVJ_MMCHR16_CTG1",
   "GL456022.2": "CHR_129X1/SVJ_MMCHR17_CTG2",
   "GL455990.1": "CHR_A/J_MMCHR13_CTG1",
   "GL455989.1": "CHR_BALB/C_MMCHR7_CTG1",
   "GL456068.1": "CHR_BALB/C_MMCHR12_CTG1",
   "JH584316.1": "CHR_CAST/EI_MMCHR11_CTG1",
   "JH584317.1": "CHR_CAST/EI_MMCHR11_CTG3",
   "JH584318.1": "CHR_CAST/EI_MMCHR18_CTG1",
   "JH584320.1": "CHR_MMCHR1_NOD_IDD5_1",
   "JH584321.1": "CHR_MMCHR1_NOD_IDD5_3",
   "JH584322.1": "CHR_MMCHR1_NOD_IDD5_4",
   "GL456042.2": "CHR_MMCHR3_NOD_IDD18_1",
   "GL456044.2": "CHR_MMCHR3_NOD_IDD18_2",
   "GL456045.2": "CHR_MMCHR3_NODMRKTAC_CTG1",
   "GL456048.1": "CHR_MMCHR3_NOD_IDD3_1",
   "GL456049.2": "CHR_MMCHR3_NODMRKTAC_CTG2",
   "JH584323.1": "CHR_MMCHR3_NOD_IDD10_1",
   "GL456053.2": "CHR_MMCHR4_NOD_IDD9_2",
   "JH584324.1": "CHR_MMCHR4_NOD_IDD9_1",
   "JH584325.1": "CHR_MMCHR4_NOD_IDD9_1M",
   "JH584326.1": "CHR_MMCHR4_NOD_IDD9_3",
   "GL456060.2": "CHR_MMCHR11_NOD_IDD4_2",
   "JH584327.1": "CHR_MMCHR11_NOD_IDD4_1",
   "JH584328.1": "CHR_MMCHR17_NOD_IDD1",
   "GL456054.2": "CHR_MMCHR6_CHORI29_IDD6_1+2",
   "JH584264.1": "CHR_MMCHR6_CHORI29_IDD6_3",
   "JH584265.1": "CHR_MMCHR11_CHORI29_IDD4_2Q",
   "JH584266.1": "CHR_MMCHR17_CHO_IDD1",
   "JH584267.1": "CHR_MMCHR17_CHORI29_IDD16_1",
   "GL456349.1": "CHR_RIII_MMCHR12_CTG1",
   "GL456070.1": "CHR_RIII_MMCHR18_CTG1",
   "GL456009.1": "CHR_UNKNOWN_MMCHR4_CTG7",
   "GL456064.1": "CHR_UNKNOWN_MMCHR4_CTG1",
   "GL456015.1": "CHR_UNKNOWN_MMCHR10_CTG3",
   "GL456069.1": "CHR_UNKNOWN_MMCHR17_CTG3",
   "JH584319.1": "CHR_UNKNOWN_MMCHR19_CTG2",
   "GL456075.1": "CHR_129S7/SVEVBRD-HPRT-B-M2_MMCHR4_CTG2",
   "GL456076.1": "CHR_129S7/SVEVBRD-HPRT-B-M2_MMCHR4_CTG3",
   "GL456077.1": "CHR_129S7/SVEVBRD-HPRT-B-M2_MMCHR4_CTG4",
   "JH584268.1": "CHR_129S7/SVEVBRD-HPRT-B-M2_MMCHR4_CTG5",
   "JH584269.1": "CHR_129S7/SVEVBRD-HPRT-B-M2_MMCHR4_CTG6",
   "GL456078.1": "CHR_129S7/SVEVBRD-HPRT-B-M2_MMCHR12_CTG2",
   "JH584270.1": "CHR_129S7/SVEVBRD-HPRT-B-M2_MMCHR15_CTG1"
        }

mm10_ensembl2ucsc = {v:k for k,v in mm10_ucsc2ensembl.items()}
mm10_ensembl2ucsc_patches = {v:k for k,v in mm10_ucsc2ensembl_patches.items()}
